@@ -6,7 +6,8 @@ from tinylinks.models import Tinylink
 
 
 class TinylinkAdmin(admin.ModelAdmin):
-    list_display = ('user', 'short_url', 'long_url', 'last_checked')
+    list_display = ('short_url', 'long_url', 'amount_of_views', 'user',
+                    'last_checked')
     search_fields = ['short_url', 'long_url']
     form = TinylinkAdminForm
 
